@@ -1,18 +1,19 @@
 package Lingua::JA::FindDates;
 use warnings;
 use strict;
-
+use Carp qw/carp croak cluck/;
+use utf8;
 use 5.010000;
+
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK= qw/subsjdate kanji2number seireki_to_nengo nengo_to_seireki
-		   regjnums/;
+		   regjnums @jdatere/;
 our %EXPORT_TAGS = (
     all => \@EXPORT_OK,
 );
-our $VERSION = '0.025';
-use Carp qw/carp croak cluck/;
-use utf8;
+
+our $VERSION = '0.026';
 
 # Kanji number conversion table.
 
@@ -259,7 +260,7 @@ my $separators = qr/\h*[〜−~]\h*/;
 
 # This a list of date regular expressions.
 
-my @jdatere = (
+our @jdatere = (
 
     # Match an empty string like 平成 月 日 as found on a form etc.
 
@@ -625,11 +626,15 @@ sub default_make_date
 	$date = "DD" if $date == 32;
 	if ($year) {
 	    $edate .= "$date, $year";
-	} else {
+	}
+	else {
 	    $edate .= "$date";
 	}
-    } elsif ($year) {
-	$edate .= " " if length ($edate);
+    }
+    elsif ($year) {
+	if (length ($edate) > 0) {
+	    $edate .= " ";
+	}
 	$edate .= $year;
     }
     return $edate;
@@ -718,16 +723,6 @@ sub default_make_date_interval
     return $einterval;
 }
 
-# If you want to see what the module is doing, set
-#
-#   $Lingua::JA::FindDates::verbose = 1;
-#
-# This makes L<subsjdate> print out each regular expression and reports
-# whether it matched, which looks like this:
-#
-#   Looking for y in ([０-９0-9]{4}|[十六七九五四千百二一八三]?千[十六七九五四千百二一八三]*)\h*年
-#   Found '千九百六十六年': Arg 0: 1966 -> '1966'
-
 our $verbose = 0;
 
 sub subsjdate
@@ -1014,4 +1009,3 @@ sub regjnums
 
 1;
 
-__END__
